pub struct Ogk<S = Qn> { /* private fields */ }Expand description
A configured OGK estimator, generic over the robust univariate scale (the
default Qn is Maronna & Zamar’s recommendation; the location functional
paired with it is the median).
Implementations
Sourceimpl<S: ScaleEstimator> Ogk<S>
impl<S: ScaleEstimator> Ogk<S>
Sourcepub fn new(scale: S) -> Self
pub fn new(scale: S) -> Self
Create an OGK estimator with the given robust scale, two orthogonalization iterations and reweighting on.
Sourcepub fn n_iter(self, n: usize) -> Self
pub fn n_iter(self, n: usize) -> Self
Set the number of orthogonalization iterations (default 2).
Sourcepub fn reweight(self, on: bool) -> Self
pub fn reweight(self, on: bool) -> Self
Enable or disable the one-step reweighting (default true).
Sourcepub fn fit(&self, x: &Array2<f64>) -> Result<ScatterFit, RobustError>
pub fn fit(&self, x: &Array2<f64>) -> Result<ScatterFit, RobustError>
Fit the estimator to the n × p data matrix x.